---
title: <span class="badge object-type-scalar"></span> BitsSI
---
# <span class="badge object-type-scalar"></span> BitsSI

Data: bits(SI)

## Definition

```python
# Data: bits(SI)
BitsSI: typing.Literal["bydecbitstes"] = "bydecbitstes"
```
